| check_data | R Documentation |
Checks column names, values, number of rows and key for a data.frame.
check_data(
x,
values = NULL,
exclusive = FALSE,
order = FALSE,
nrow = numeric(0),
key = character(0),
x_name = NULL
)
x |
The object to check. |
values |
A uniquely named list of atomic vectors of the column values. |
exclusive |
A flag specifying whether x must only include columns named in values. |
order |
A flag specifying whether the order of columns in x must match names in values. |
nrow |
A flag or a whole numeric vector of the value, value range or possible values. |
key |
A character vector of the columns that represent a unique key. |
x_name |
A string of the name of object x or NULL. |
The values of each column are checked using check_values().
See its details for the rules including those for factor levels
and missing values.
values is reduced with unique(),
so a column whose class lacks a correct unique() method
is checked against the wrong values.
In particular unique() on a lubridate Period vector discards
everything but the seconds,
which collapses values and silently changes the check applied
(see https://github.com/tidyverse/lubridate/issues/1154).
Either define unique.Period() in your own code
or convert the column and values to a class with a correct
unique() method,
such as the number of seconds with as.numeric(lubridate::as.duration(x)).
An informative error if the test fails or an invisible copy of x.
Other check:
check_dim(),
check_dirs(),
check_files(),
check_key(),
check_length(),
check_names(),
check_values()
check_data(data.frame())
check_data(data.frame(x = 2), list(x = 1))
try(check_data(data.frame(x = 2), list(y = 1L)))
try(check_data(data.frame(x = 2), list(y = 1)))
try(check_data(data.frame(x = 2), nrow = 2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.