check_values: Check Values and Class

View source: R/check-values.R

check_valuesR Documentation

Check Values and Class

Description

Checks values and S3 class of an atomic object.

Usage

check_values(x, values, x_name = NULL)

Arguments

x

The object to check.

values

An atomic vector specifying the S3 class and possible values.

x_name

A string of the name of object x or NULL.

Details

To check the class simply pass a vector of the desired class.

To check that x does not include missing values pass a single non-missing value (of the correct class).

To allow it to include missing values include a missing value.

To check that it only includes missing values only pass a missing value (of the correct class).

To check the range of the values in x pass two non-missing values (as well as the missing value if required).

To check that x only includes specific values pass three or more non-missing values.

In the case of a factor if values has two or more levels then the levels of x must be identical, including their order, to the levels of values. A factor with less than two levels only checks that x is a factor. Thus factor(1) allows any factor without missing values, factor(c(1, NA)) any factor with or without missing values and factor(NA) any factor with all missing values.

Value

An informative error if the test fails or an invisible copy of x.

See Also

Other check: check_data(), check_dim(), check_dirs(), check_files(), check_key(), check_length(), check_names()

Examples

check_values(1, numeric(0))
check_values(1, 2)
try(check_values(1, 1L))
try(check_values(NA_real_, 1))

chk documentation built on Sept. 3, 2026, 9:07 a.m.