Checks if not all values in values using
!any(x %in% values) || !length(x)
Value
The chk_ function throws an informative error if the test fails or
returns the original object if successful so it can used in pipes.
The vld_ function returns a flag indicating whether the test was met.
See also
For more details about the use of this function,
please read the article
vignette("chk-families").
Other set_checkers:
chk_orderset(),
chk_setequal(),
chk_subset(),
chk_superset()