| chk_orderset | R Documentation |
Checks if the first occurrence of each shared element
in x is equivalent to the first occurrence of each shared element in values using
vld_equivalent(unique(x[x %in% values]), values[values %in% x]).
chk_orderset(x, values, x_name = NULL)
vld_orderset(x, values)
x |
The object to check. |
values |
A vector of the permitted values. |
x_name |
A string of the name of object x or NULL. |
The chk_ function throws an informative error if the test fails.
The vld_ function returns a flag indicating whether the test was met.
vld_orderset(): Validate Set Ordered
vld_equivalent()
unique()
For more details about the use of this function,
please read the article
vignette("chk-families").
Other set_checkers:
chk_not_subset(),
chk_setequal(),
chk_subset(),
chk_superset()
# chk_orderset
chk_orderset(1:2, 1:2)
try(chk_orderset(2:1, 1:2))
# vld_orderset
vld_orderset(1, 1)
vld_orderset(1:2, 2:1)
vld_orderset(1, 2:1)
vld_orderset(1:2, 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.