Checks inherits from S3 class using
inherits(x, class) && !isS4(x) && !inherits(x, "R6")
Value
The chk_ function throws an informative error if the test fails or
returns the original object if successful so it can used in pipes.
The vld_ function returns a flag indicating whether the test was met.
Details
Note that base objects and S7 classes are considered S3 objects.
See also
For more details about the use of this function,
please read the article
vignette("chk-families").
Other id_checkers:
chk_class(),
chk_data(),
chk_is(),
chk_s3_class_strict(),
chk_s4_class()
Examples
# chk_s3_class
chk_s3_class(1, "numeric")
chk_s3_class(factor(1), "factor")
try(chk_s3_class(getClass("MethodDefinition"), "classRepresentation"))
#> Error in eval(expr, envir) :
#> `getClass("MethodDefinition")` must inherit from S3 class 'classRepresentation', not S4 class 'classRepresentation'.
# vld_s3_class
vld_s3_class(numeric(0), "numeric")
#> [1] TRUE
vld_s3_class(getClass("MethodDefinition"), "classRepresentation")
#> [1] FALSE