Learn R Programming

chk (version 0.11.0)

chk_setequal: Check Set Equal

Description

Checks if equal set using

setequal(x, values)

Usage

chk_setequal(x, values, x_name = NULL)

vld_setequal(x, values)

Value

The chk_ function throws an informative error if the test fails or returns the original object if successful so it can used in pipes.

The vld_ function returns a flag indicating whether the test was met.

Arguments

x

The object to check.

values

A vector of the permitted values.

x_name

A string of the name of object x or NULL.

Functions

  • vld_setequal(): Validate Set Equal

See Also

setequal()

For more details about the use of this function, please read the article vignette("chk-families").

Other set_checkers: chk_not_subset(), chk_orderset(), chk_subset(), chk_superset()

Examples

Run this code
# chk_setequal
chk_setequal(1:2, 2:1)
try(chk_setequal(1, 1:2))
# vld_setequal
vld_setequal(1, 1)
vld_setequal(1:2, 2:1)
vld_setequal(1, 2:1)
vld_setequal(1:2, 2)

Run the code above in your browser using DataLab