chk_subset: Check Subset

View source: R/chk-subset.R

chk_subsetR Documentation

Check Subset

Description

Checks if all values in values using

all(x %in% values)

Pay attention to the order of the arguments value and x in this function compared to chk_superset()

Usage

chk_subset(x, values, x_name = NULL)

vld_subset(x, values)

Arguments

x

The object to check.

values

A vector of the permitted values.

x_name

A string of the name of object x or NULL.

Value

The chk_ function throws an informative error if the test fails or returns the original object if successful so it can used in pipes.

The vld_ function returns a flag indicating whether the test was met.

Functions

  • vld_subset(): Validate Subset

See Also

all()

For more details about the use of this function, please read the article vignette("chk-families").

Other set_checkers: chk_not_subset(), chk_orderset(), chk_setequal(), chk_superset()

Examples

# chk_subset
chk_subset(1, 1:10)
try(chk_subset(11, 1:10))
# vld_subset
vld_subset(numeric(0), 1:10)
vld_subset(1, 1:10)
vld_subset(11, 1:10)

chk documentation built on Sept. 3, 2026, 9:07 a.m.