powered by
Checks if non-missing complex scalar using
is.complex(x) && length(x) == 1L && !anyNA(x)
chk_complex_number(x, x_name = NULL)vld_complex_number(x)
vld_complex_number(x)
The chk_ function throws an informative error if the test fails or returns the original object if successful so it can used in pipes.
chk_
The vld_ function returns a flag indicating whether the test was met.
vld_
The object to check.
A string of the name of object x or NULL.
vld_complex_number(): Validate Complex Number
vld_complex_number()
is.complex()
length()
For more details about the use of this function, please read the article chk families.
Other scalar_checkers: chk_count(), chk_date(), chk_date_time(), chk_false(), chk_flag(), chk_lgl(), chk_number(), chk_scalar(), chk_string(), chk_true(), chk_tz(), chk_whole_number()
chk_count()
chk_date()
chk_date_time()
chk_false()
chk_flag()
chk_lgl()
chk_number()
chk_scalar()
chk_string()
chk_true()
chk_tz()
chk_whole_number()
# chk_complex_number chk_complex_number(as.complex(1.1)) try(chk_complex_number(1.1)) # vld_complex_number vld_complex_number(as.complex(2))
Run the code above in your browser using DataLab