Learn R Programming

chk (version 0.11.0)

chk_not_subset: Check Not Subset

Description

Checks if not all values in values using

!any(x %in% values) || !length(x)

Usage

chk_not_subset(x, values, x_name = NULL)

vld_not_subset(x, values)

Value

The chk_ function throws an informative error if the test fails or returns the original object if successful so it can used in pipes.

The vld_ function returns a flag indicating whether the test was met.

Arguments

x

The object to check.

values

A vector of the permitted values.

x_name

A string of the name of object x or NULL.

Functions

  • vld_not_subset(): Validate Not Subset

See Also

any()

length()

For more details about the use of this function, please read the article vignette("chk-families").

Other set_checkers: chk_orderset(), chk_setequal(), chk_subset(), chk_superset()

Examples

Run this code
# chk_not_subset
chk_not_subset(11, 1:10)
try(chk_not_subset(1, 1:10))
# vld_not_subset
vld_not_subset(numeric(0), 1:10)
vld_not_subset(1, 1:10)
vld_not_subset(11, 1:10)

Run the code above in your browser using DataLab