powered by
Checks if not all values in values using
!any(x %in% values) || !length(x)
chk_not_subset(x, values, x_name = NULL)vld_not_subset(x, values)
vld_not_subset(x, values)
The chk_ function throws an informative error if the test fails or returns the original object if successful so it can used in pipes.
chk_
The vld_ function returns a flag indicating whether the test was met.
vld_
The object to check.
A vector of the permitted values.
A string of the name of object x or NULL.
vld_not_subset(): Validate Not Subset
vld_not_subset()
any()
length()
For more details about the use of this function, please read the article vignette("chk-families").
vignette("chk-families")
Other set_checkers: chk_orderset(), chk_setequal(), chk_subset(), chk_superset()
chk_orderset()
chk_setequal()
chk_subset()
chk_superset()
# chk_not_subset chk_not_subset(11, 1:10) try(chk_not_subset(1, 1:10)) # vld_not_subset vld_not_subset(numeric(0), 1:10) vld_not_subset(1, 1:10) vld_not_subset(11, 1:10)
Run the code above in your browser using DataLab