Learn R Programming

chk (version 0.11.0)

chk_number: Check Number

Description

Checks if non-missing numeric scalar using

is.numeric(x) && length(x) == 1L && !anyNA(x)

Pass: 1, 2L, log(10), -Inf

Fail: "a", 1:3, NA_real_

Usage

chk_number(x, x_name = NULL)

vld_number(x)

Value

The chk_ function throws an informative error if the test fails or returns the original object if successful so it can used in pipes.

The vld_ function returns a flag indicating whether the test was met.

Arguments

x

The object to check.

x_name

A string of the name of object x or NULL.

Functions

  • vld_number(): Validate Number

See Also

is.numeric()

length()

For more details about the use of this function, please read the article vignette("chk-families").

Other data_type_checkers: chk_character(), chk_character_or_factor(), chk_complex(), chk_double(), chk_environment(), chk_factor(), chk_integer(), chk_logical(), chk_numeric(), chk_raw()

Other scalar_checkers: chk_complex_number(), chk_count(), chk_date(), chk_date_time(), chk_false(), chk_flag(), chk_lgl(), chk_scalar(), chk_string(), chk_true(), chk_tz(), chk_whole_number()

Examples

Run this code
# chk_number
chk_number(1.1)
try(chk_number(TRUE))
# vld_number
vld_number(1.1)

Run the code above in your browser using DataLab