Checks if the first occurrence of each shared element
in x is equivalent to the first occurrence of each shared element in values using
vld_equivalent(unique(x[x %in% values]), values[values %in% x]).
Value
The chk_ function throws an informative error if the test fails.
The vld_ function returns a flag indicating whether the test was met.
See also
For more details about the use of this function,
please read the article
vignette("chk-families").
Other set_checkers:
chk_not_subset(),
chk_setequal(),
chk_subset(),
chk_superset()
Examples
# chk_orderset
chk_orderset(1:2, 1:2)
try(chk_orderset(2:1, 1:2))
#> Error in eval(expr, envir) :
#> `2:1` must have each of the following elements in the following order: 1, 2.
# vld_orderset
vld_orderset(1, 1)
#> [1] TRUE
vld_orderset(1:2, 2:1)
#> [1] FALSE
vld_orderset(1, 2:1)
#> [1] TRUE
vld_orderset(1:2, 2)
#> [1] TRUE