Learn R Programming

chk (version 0.11.0)

chk_r6_class: Check Inherits from R6 Class

Description

Checks inherits from R6 class using

inherits(x, "R6") && inherits(x, class)

Usage

chk_r6_class(x, class, x_name = NULL)

vld_r6_class(x, class)

Value

The chk_ function throws an informative error if the test fails or returns the original object if successful so it can used in pipes.

The vld_ function returns a flag indicating whether the test was met.

Arguments

x

The object to check.

class

A character vector specifying the possible class values.

x_name

A string of the name of object x or NULL.

Functions

  • vld_r6_class(): Validate Inherits from R6 Class

Details

All R6 objects inherit from the class 'R6', so chk_r6_class(x, "R6") checks that x is an R6 object of any class. R6 class generators (as returned by R6::R6Class()) are not themselves R6 objects.

See Also

inherits()

For more details about the use of this function, please read the article vignette("chk-families").

Other id_checkers: chk_class(), chk_data(), chk_is(), chk_s3_class(), chk_s3_class_strict(), chk_s4_class()

Examples

Run this code
# chk_r6_class
chk_r6_class(R6::R6Class("exampleR6class")$new(), "exampleR6class")
try(chk_r6_class(1, "numeric"))
# vld_r6_class
vld_r6_class(R6::R6Class("exampleR6class")$new(), "exampleR6class")
vld_r6_class(1, "numeric")

Run the code above in your browser using DataLab