Learn R Programming

chk (version 0.11.0)

chk_s3_class: Check Type

Description

Checks inherits from S3 class using

inherits(x, class) && !isS4(x) && !inherits(x, "R6")

Usage

chk_s3_class(x, class, x_name = NULL)

vld_s3_class(x, class)

Value

The chk_ function throws an informative error if the test fails or returns the original object if successful so it can used in pipes.

The vld_ function returns a flag indicating whether the test was met.

Arguments

x

The object to check.

class

A character vector specifying the possible class values.

x_name

A string of the name of object x or NULL.

Functions

  • vld_s3_class(): Validate Inherits from S3 Class

Details

Note that base objects and S7 classes are considered S3 objects.

See Also

inherits()

typeof()

For more details about the use of this function, please read the article vignette("chk-families").

Other id_checkers: chk_class(), chk_data(), chk_is(), chk_r6_class(), chk_s3_class_strict(), chk_s4_class()

Examples

Run this code
# chk_s3_class
chk_s3_class(1, "numeric")
chk_s3_class(factor(1), "factor")
try(chk_s3_class(getClass("MethodDefinition"), "classRepresentation"))
# vld_s3_class
vld_s3_class(numeric(0), "numeric")
vld_s3_class(getClass("MethodDefinition"), "classRepresentation")

Run the code above in your browser using DataLab