powered by
Checks if all values in values using
all(x %in% values)
Pay attention to the order of the arguments value and x in this function compared to chk_superset()
value
x
chk_superset()
chk_subset(x, values, x_name = NULL)vld_subset(x, values)
vld_subset(x, values)
The chk_ function throws an informative error if the test fails or returns the original object if successful so it can used in pipes.
chk_
The vld_ function returns a flag indicating whether the test was met.
vld_
The object to check.
A vector of the permitted values.
A string of the name of object x or NULL.
vld_subset(): Validate Subset
vld_subset()
all()
For more details about the use of this function, please read the article vignette("chk-families").
vignette("chk-families")
Other set_checkers: chk_not_subset(), chk_orderset(), chk_setequal(), chk_superset()
chk_not_subset()
chk_orderset()
chk_setequal()
# chk_subset chk_subset(1, 1:10) try(chk_subset(11, 1:10)) # vld_subset vld_subset(numeric(0), 1:10) vld_subset(1, 1:10) vld_subset(11, 1:10)
Run the code above in your browser using DataLab