| chkor_vld | R Documentation |
Chk OR
chkor_vld(..., x_name = NULL)
... |
Multiple A common mistake is to pass
|
x_name |
A string of the name of the object to use in the error
message or NULL. If a string it is passed to each of the |
An informative error if the test fails.
chk_null_or()
chkor_vld()
chkor_vld(vld_flag(TRUE))
try(chkor_vld(vld_flag(1)))
try(chkor_vld(vld_flag(1), vld_flag(2)))
chkor_vld(vld_flag(1), vld_flag(TRUE))
try(chkor_vld(vld_flag(1), vld_number(1), x_name = "`arg`"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.