Learn R Programming

chk (version 0.11.0)

chkor_vld: Chk OR

Description

Chk OR

Usage

chkor_vld(..., x_name = NULL)

Value

An informative error if the test fails.

Arguments

...

Multiple vld_ calls.

A common mistake is to pass chk_ calls.

chkor_vld() is relatively slow. If at all possible use chk_null_or() or first test using the individual vld_ functions and then call chkor_vld() to generate an informative error message.

x_name

A string of the name of the object to use in the error message or NULL. If a string it is passed to each of the chk_ calls so that the error message refers to x_name rather than the deparsed vld_ arguments.

See Also

chk_null_or()

Examples

Run this code
chkor_vld()
chkor_vld(vld_flag(TRUE))
try(chkor_vld(vld_flag(1)))
try(chkor_vld(vld_flag(1), vld_flag(2)))
chkor_vld(vld_flag(1), vld_flag(TRUE))
try(chkor_vld(vld_flag(1), vld_number(1), x_name = "`arg`"))

Run the code above in your browser using DataLab