message_chk: Construct Tidyverse Style Message

View source: R/err.R

message_chkR Documentation

Construct Tidyverse Style Message

Description

If tidy = TRUE constructs a tidyverse style message by

Usage

message_chk(..., n = NULL, tidy = TRUE)

Arguments

...

Multiple objects that are converted to a string using paste0(..., collapse = '').

n

The value of n for converting sprintf-like types.

tidy

A flag specifying whether capitalize the first character and add a missing period.

Details

  • Capitalizing the first character if possible.

  • Adding a trailing . if missing.

Also if n != NULL replaces the recognized sprintf-like types.

Value

A string of the message.

sprintf-like types

The following recognized sprintf-like types can be used in a message:

n

The value of n.

s

” if n == 1 otherwise 's'

es

” if n == 1 otherwise 'es'

r

'is' if n == 1 otherwise 'are'

y

'y' if n == 1 otherwise 'ie'

ies

'y' if n == 1 otherwise 'ies'

⁠%⁠

A literal '%'.

The types are replaced in a single left to right pass, so %% escapes a literal '%' and a replacement is never rescanned. A '%' that does not start a recognized type is left as is.

Examples

message_chk("there %r %n", " problem director%y%s")
message_chk("there %r %n", " problem director%y%s", n = 1)
message_chk("There %r %n", " problem director%y%s.", n = 3)
message_chk("there %r %n problem class%es", n = 1)
message_chk("there %r %n problem class%es", n = 3)
message_chk("%n%% of value%s", n = 2)

chk documentation built on Sept. 3, 2026, 9:07 a.m.